@@ -1,5 +1,7 @@
 import argparse
+import logging
 import sys
+import threading
 from pathlib import Path
 
 from textual import events
@@ -10,7 +12,11 @@ from textual.widgets import Header
 
 from . import __version__
 from .loader import KeyValueLoader
+from .log import setup_logging
 from .renderables.namespace_tree import EntryClick
+from .system import do_every
+from .system import timer
+from .widgets.details import Details
 from .widgets.footer import Footer
 from .widgets.help import Help
 from .widgets.levels import Levels
@@ -18,11 +24,16 @@ from .widgets.namespaces import Namespaces
 from .widgets.recordinfo import RecordInfo
 from .widgets.records import Records
 
+logging.basicConfig(level=logging.ERROR)
+
+MODULE_LOGGER = logging.getLogger("Textual")
+
 
 class TextualLog(App):
 
     show_help = Reactive(False)
     show_namespaces = Reactive(False)
+    show_details = Reactive(False)
 
     # The namespace_tree is just for demonstration purposes. The namespace should be a
     # tree like structure with proper navigation and the possibility to add and remove nodes.
@@ -39,6 +50,8 @@ class TextualLog(App):
         self.filename = filename
         self.cursor = 0
         self.loader = None
+        self.details_widget = None
+        self.follow = False
 
     async def on_mount(self, event: events.Mount) -> None:
         """
@@ -51,10 +64,17 @@ class TextualLog(App):
         self.help_widget = Help()
         self.help_widget.visible = False
 
-        await self.view.dock(Header(), edge="top")
-        await self.view.dock(Footer(), edge="bottom")
+        self.details_widget = Details()
+        self.details_widget.visible = False
+
+        self.header = Header()
+        self.footer = Footer()
+
+        await self.view.dock(self.header, edge="top")
+        await self.view.dock(self.footer, edge="bottom")
         await self.view.dock(self.namespaces, edge="left", size=40, z=1)
         await self.view.dock(self.help_widget, edge="right", size=40, z=1)
+        await self.view.dock(self.details_widget, size=20, z=1)
         grid = await self.view.dock_grid(edge="left", name="left")
 
         grid.add_column(size=30, name="left")
@@ -89,6 +109,29 @@ class TextualLog(App):
 
             self.records.update(self.loader.get_records(0, 500, None))
 
+        # self.set_interval(2.0, self.collect_data)
+
+        self._reload_thread = threading.Thread(
+            target=do_every, args=(2.0, self.collect_data))
+        self._reload_thread.daemon = True
+        self._reload_thread.start()
+
+    @timer(level=logging.DEBUG)
+    def collect_data(self):
+        if not self.follow or self.loader is None:
+            return
+
+        self.loader.load()
+
+        # The height of the text area of the Records panel
+
+        height = self.records.size.height - 2
+        size = self.loader.size()
+
+        self.cursor = max(0, size - height)
+        self.records.replace(self.loader.get_records(self.cursor, height, self.levels))
+        self.records.refresh(layout=True)
+
     async def on_load(self) -> None:
         """
         Sent before going in to application mode. This method is called before on_mount().
@@ -128,9 +171,14 @@ class TextualLog(App):
             self.show_namespaces = not self.show_namespaces
         elif event.key == "r":
             self.loader.load()
+        elif event.key == "f":
+            self.follow = not self.follow
+            self.header.style = "white on dark_red" if self.follow else "white on dark_green"
+            # self.collect_data()
         elif event.key == Keys.Escape:
             self.show_help = False
             self.show_namespaces = False
+            self.show_details = False
         elif event.key == Keys.Down:
             self.cursor = min(size, self.cursor + 1)
             self.records.replace(self.loader.get_records(self.cursor, height, self.levels))
@@ -144,7 +192,7 @@ class TextualLog(App):
             self.cursor = max(0, self.cursor-(height-1))
             self.records.replace(self.loader.get_records(self.cursor, height, self.levels))
         elif event.key == Keys.End:
-            self.cursor = size - height
+            self.cursor = max(0, size - height)
             self.records.replace(self.loader.get_records(self.cursor, height, self.levels))
         elif event.key == Keys.Home:
             self.cursor = 0
@@ -160,6 +208,10 @@ class TextualLog(App):
         """Called when show_help changes."""
         self.help_widget.visible = show_help
 
+    async def watch_show_details(self, show_details: bool) -> None:
+        """Called when show_details changes."""
+        self.details_widget.visible = show_details
+
     async def action_toggle_help(self) -> None:
         """Called when bound help key is pressed."""
         self.show_help = not self.show_help
@@ -193,7 +245,15 @@ def main():
         "-l",
         type=str,
         default=None,
-        help="debug log file",
+        help="the full path to the log file that you want to follow",
+    )
+
+    parser.add_argument(
+        "--debug",
+        "-d",
+        action="store_true",
+        default=False,
+        help="send debugging information to the debug log files",
     )
 
     args = parser.parse_args()
@@ -201,7 +261,12 @@ def main():
     if args.log and not Path(args.log).exists():
         raise FileNotFoundError(f"No such file {args.log}")
 
-    TextualLog.run(title="Textual Log Viewer", log=None, filename=args.log)
+    log_filename = "textual.log" if args.debug else None
+
+    if args.debug:
+        setup_logging("textualog.log")
+
+    TextualLog.run(title="Textual Log Viewer", log=log_filename, filename=args.log)
 
 
 def _get_version_text():
