@@ -1,3 +1,4 @@
+from rich.console import RenderableType
 from textual.widgets import Footer
 
 
@@ -6,5 +7,5 @@ class Footer(Footer):
     def on_mount(self) -> None:
         self.layout_size = 1
 
-    def render(self):
+    def render(self) -> RenderableType:
         return super().render()
