@@ -4,6 +4,7 @@ from typing import Optional
 
 from rich.panel import Panel
 from rich.text import Text
+from textual import events
 from textual.reactive import Reactive
 from textual.widget import Widget
 
@@ -26,8 +27,12 @@ class RecordInfo(Widget):
         # self.layout_fraction = 1
         ...
 
+    async def on_click(self, event: events.Click) -> None:
+        self.app.show_details = True
+
     def set(self, record: LogRecord):
         self.record = record
+        self.app.details_widget.set(self.record)
 
     def render(self) -> Panel:
 
